==> setuptools-wrapper-0.2.3.tar.gz: setuptools-wrapper-0.2.3/README.md <==
<!--
    =====================================
    generator=datazen
    version=3.1.0
    hash=f62e7926101137426b8edba2efe30343
    =====================================
-->

# setuptools-wrapper ([0.2.3](https://pypi.org/project/setuptools-wrapper/))

[![python](https://img.shields.io/pypi/pyversions/setuptools-wrapper.svg)](https://pypi.org/project/setuptools-wrapper/)
![Build Status](https://github.com/vkottler/setuptools-wrapper/workflows/Python%20Package/badge.svg)
[![codecov](https://codecov.io/gh/vkottler/setuptools-wrapper/branch/master/graphs/badge.svg?branch=master)](https://codecov.io/github/vkottler/setuptools-wrapper)
![PyPI - Status](https://img.shields.io/pypi/status/setuptools-wrapper)
![Dependents (via libraries.io)](https://img.shields.io/librariesio/dependents/pypi/setuptools-wrapper)

*A simple interface to setuptools's setup function.*

See also: [generated documentation](https://vkottler.github.io/python/pydoc/setuptools_wrapper.html)
(created with [`pydoc`](https://docs.python.org/3/library/pydoc.html)).

## Python Version Support

This package is tested with the following Python minor versions:

* [`python3.7`](https://docs.python.org/3.7/)
* [`python3.8`](https://docs.python.org/3.8/)
* [`python3.9`](https://docs.python.org/3.9/)
* [`python3.10`](https://docs.python.org/3.10/)

## Platform Support

This package is tested on the following platforms:

* `ubuntu-latest`
* `macos-latest`
* `windows-latest`

# Introduction

That's it. I personally think there are way too many configuration options when
"packaging" software and I want to homogenize my own packages. Thus:
`setuptools-wrapper`.

# Internal Dependency Graph

A coarse view of the internal structure and scale of
`setuptools-wrapper`'s source.
Generated using [pydeps](https://github.com/thebjorn/pydeps) (via
`mk python-deps`).

![setuptools-wrapper's Dependency Graph](im/pydeps.svg)

==> setuptools-wrapper-0.2.4.tar.gz: setuptools-wrapper-0.2.4/README.md <==
<!--
    =====================================
    generator=datazen
    version=3.1.2
    hash=d33d73fa711b3715c68d36e6a6ded29c
    =====================================
-->

# setuptools-wrapper ([0.2.4](https://pypi.org/project/setuptools-wrapper/))

[![python](https://img.shields.io/pypi/pyversions/setuptools-wrapper.svg)](https://pypi.org/project/setuptools-wrapper/)
![Build Status](https://github.com/vkottler/setuptools-wrapper/workflows/Python%20Package/badge.svg)
[![codecov](https://codecov.io/gh/vkottler/setuptools-wrapper/branch/master/graphs/badge.svg?branch=master)](https://codecov.io/github/vkottler/setuptools-wrapper)
![PyPI - Status](https://img.shields.io/pypi/status/setuptools-wrapper)
![Dependents (via libraries.io)](https://img.shields.io/librariesio/dependents/pypi/setuptools-wrapper)

*A simple interface to setuptools's setup function.*

## Documentation

### Generated

* By [sphinx-apidoc](https://vkottler.github.io/python/sphinx/setuptools-wrapper)
(What's [`sphinx-apidoc`](https://www.sphinx-doc.org/en/master/man/sphinx-apidoc.html)?)
* By [pydoc](https://vkottler.github.io/python/pydoc/setuptools_wrapper.html)
(What's [`pydoc`](https://docs.python.org/3/library/pydoc.html)?)

## Python Version Support

This package is tested with the following Python minor versions:

* [`python3.8`](https://docs.python.org/3.8/)
* [`python3.9`](https://docs.python.org/3.9/)
* [`python3.10`](https://docs.python.org/3.10/)
* [`python3.11`](https://docs.python.org/3.11/)

## Platform Support

This package is tested on the following platforms:

* `ubuntu-latest`
* `macos-latest`
* `windows-latest`

# Introduction

That's it. I personally think there are way too many configuration options when
"packaging" software and I want to homogenize my own packages. Thus:
`setuptools-wrapper`.

# Internal Dependency Graph

A coarse view of the internal structure and scale of
`setuptools-wrapper`'s source.
Generated using [pydeps](https://github.com/thebjorn/pydeps) (via
`mk python-deps`).

![setuptools-wrapper's Dependency Graph](im/pydeps.svg)
